const GOODS_URI = require("../config.js").GOODS_URI;
const req = require("../utils/request").httpReq;

/**
 * 示例
 *  exports.方法名 = async ctx => {
 *    const url = `${设置好的域名}/向服务端发送的请求地址`;
 *    const opts = {
 *      url,
 *      method:"发送什么请求"，
 *      qs: ctx.request.query （get请求的参数）
 *      body：ctx.request.body （post请求的参数）
 *      json：boolean (是否转换为json)
 *    };
 *    ctx.body = await req(ctx,opts); 将发送请求后的数据传递给前端页面
 *  };
 */
// 获取分类
exports.getCategoryList = async ctx => {
  const url = `${GOODS_URI}/goods/background/get_goods_category_list`;
  const opts = {
    url,
    method: "GET"
  };
  ctx.body = await req(ctx, opts);
};
// 获取商品列表
exports.getList = async ctx => {
  const url = `${GOODS_URI}/goods/background/get_goods_list`;
  const opts = {
    url,
    method: "GET",
    qs: ctx.request.query
  };
  ctx.body = await req(ctx, opts);
};
// 商品上架
exports.putOnline = async ctx => {
  const url = `${GOODS_URI}/goods/background/online`;
  const opts = {
    url,
    method: "POST",
    json: true,
    body: ctx.request.body
  };
  ctx.body = await req(ctx, opts);
};
// 商品下架
exports.putOffline = async ctx => {
  const url = `${GOODS_URI}/goods/background/offline`;
  const opts = {
    url,
    method: "POST",
    json: true,
    body: ctx.request.body
  };
  ctx.body = await req(ctx, opts);
};
// 获取商品详情列表
exports.getGoodsInfo = async ctx => {
  const url = `${GOODS_URI}/goods/background/get_goods_info`;
  const opts = {
    url,
    method: "GET",
    qs: ctx.request.query
  };
  ctx.body = await req(ctx, opts);
};
// 商品审核通过
exports.postSuccess = async ctx => {
  const opts = {
    url: `${GOODS_URI}/goods/background/audit_pass`,
    method: "POST",
    json: true,
    body: ctx.request.body
  };
  ctx.body = await req(ctx, opts);
};
// 营销活动列表
exports.getMarketingList = async ctx => {
  const url = `${GOODS_URI}/marketing/background/marketing_list`;
  const opts = {
    url,
    method: "POST",
    json: true,
    body: ctx.request.body
  };
  ctx.body = await req(ctx, opts);
};
// 检查商品名称是否被占用
exports.checkGoodsName = async ctx => {
  const opts = {
    url: `${GOODS_URI}/goods/background/check_goods_name`,
    method: "POST",
    json: true,
    body: ctx.request.body
  };
  ctx.body = await req(ctx, opts);
};
// 获取查询活动列表
exports.getFindGoodsList = async ctx => {
  const url = `${GOODS_URI}/marketing/background/goods_list`;
  const opts = {
    url,
    method: "POST",
    json: true,
    body: ctx.request.body
  };
  ctx.body = await req(ctx, opts);
};
// 审核拒绝
exports.auditReject = async ctx => {
  const opts = {
    url: `${GOODS_URI}/goods/background/audit_reject`,
    method: "POST",
    json: true,
    body: ctx.request.body
  };
  ctx.body = await req(ctx, opts);
}

// 添加活动列表
exports.getAddMarketingList = async ctx => {
  const url = `${GOODS_URI}/marketing/background/add_marketing`;
  const opts = {
    url,
    method: "POST",
    json: true,
    body: ctx.request.body
  };
  ctx.body = await req(ctx, opts);
};
// 获取门店列表
exports.getShopsList = async ctx => {
  const opts = {
    url: `${GOODS_URI}/shop/background/shop_list`,
    method: "GET",
    qs: ctx.request.query
  };
  ctx.body = await req(ctx, opts);
};
// 添加门店
exports.addShop = async ctx => {
  const opts = {
    url: `${GOODS_URI}/shop/background/add_shop`,
    method: "POST",
    json: true,
    body: ctx.request.body
  };
  ctx.body = await req(ctx, opts);
}
// 查看列表详情
exports.getMarketingInfo = async ctx => {
  const url = `${GOODS_URI}/marketing/background/marketing_info`;
  const opts = {
    url,
    method: "POST",
    json: true,
    body: ctx.request.body
  };
  ctx.body = await req(ctx, opts);
};
// 修改商品
exports.editGoods = async ctx => {
  const opts = {
    url: `${GOODS_URI}/goods/background/edit_goods`,
    method: "POST",
    json: true,
    body: ctx.request.body
  }
  ctx.body = await req(ctx, opts);
};
// 开启关闭状态
exports.updateMarketingList = async ctx => {
  const url = `${GOODS_URI}/marketing/background/update_marketing`;
  const opts = {
    url,
    method: "POST",
    json: true,
    body: ctx.request.body
  };
  const res = await req(ctx, opts);
  ctx.body = res;
};
